package MT::Plugin::EntityRefButton;

use strict;
use MT::Plugin;
@MT::Plugin::EntityRefButton::ISA = qw( MT::Plugin );

use vars qw( $VERSION $PLUGIN_NAME );
$PLUGIN_NAME = 'EntityRefButton';
$VERSION = '0.0.2';

use MT;

my $plugin = MT::Plugin::EntityRefButton->new({
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => '<MT_TRANS phrase=\'This plugin adds a convert button to the entry body and the extended body fields on the edit entry screen, which converts special characters to character entity references.\'>',
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.gr.jp/',
    l10n_class => 'EntityRefButton::L10N',
});
MT->add_plugin($plugin);
MT->add_callback('MT::App::CMS::AppTemplateSource.edit_entry', 9, $plugin, \&transform);

sub instance { $plugin; }

sub transform {
  my ($eh, $app, $tmpl) = @_;
  add_script($eh, $app, $tmpl);
  add_convert_button($eh, $app, $tmpl);
}

sub add_script {
  my ($eh, $app, $tmpl) = @_;
  # insert javascript
  my $script = <<'SCRIPT';
function convertToCharEntityRef(e) {
    if(!canFormat) return;
    var str = getSelected(e);
    if(str) {
        str = str.replace(/&/g, "&amp;");
        str = str.replace(/ /g, "&nbsp;");
        str = str.replace(/</g, "&lt;");
        str = str.replace(/>/g, "&gt;");
        str = str.replace(/"/g, "&quot;");
        setSelection(e, str);
    }
    return false;
}

SCRIPT
  $$tmpl =~ s!(}\n\n)(//-->\n</script>)!$1$script$2!is;
}

sub add_convert_button {
  my ($eh, $app, $tmpl) = @_;
  # translate button's label
  my $alt_str = $plugin->translate('Convert to character entity reference');

  # add a "convert" button to body field
  my $quote_button_for_text = <<'QUOTE_BUTTON_FOR_TEXT';
        write('<img title="<MT_TRANS phrase="Quote">" onclick="return formatStr(document.entry_form.text, \'blockquote\')" src="<TMPL_VAR NAME=STATIC_URI>images/formatting-icons/quote.gif" alt="<MT_TRANS phrase="Quote">" width="26" height="19" />');
QUOTE_BUTTON_FOR_TEXT
  my $button_for_text = <<"BUTTON_FOR_TEXT";
        write('<img title="$alt_str" onclick="return convertToCharEntityRef(document.entry_form.text)" src="<TMPL_VAR NAME=STATIC_URI>plugins/EntityRefButton/images/formatting-icons/ref.gif" alt="$alt_str" width="26" height="19" />');
BUTTON_FOR_TEXT
  $$tmpl =~ s!(\Q$quote_button_for_text\E)(\s+\}\n\})!$1$button_for_text$2!is;

  # add a "convert" button to extended body field
  my $quote_button_for_text_more = <<'QUOTE_BUTTON_FOR_TEXT_MORE';
        write('<img title="<MT_TRANS phrase="Quote">" onclick="return formatStr(document.entry_form.text_more, \'blockquote\')" src="<TMPL_VAR NAME=STATIC_URI>images/formatting-icons/quote.gif" alt="<MT_TRANS phrase="Quote">" width="26" height="19" />');
QUOTE_BUTTON_FOR_TEXT_MORE
  my $button_for_text_more = <<"BUTTON_FOR_TEXT_MORE";
        write('<img title="$alt_str" onclick="return convertToCharEntityRef(document.entry_form.text_more)" src="<TMPL_VAR NAME=STATIC_URI>plugins/EntityRefButton/images/formatting-icons/ref.gif" alt="$alt_str" width="26" height="19" />');
BUTTON_FOR_TEXT_MORE
  $$tmpl =~ s!(\Q$quote_button_for_text_more\E)(\s+\}\n\})!$1$button_for_text_more$2!is;
}

1;

__END__
